@@ -17,6 +17,7 @@ from sentry.conf import settings
 from sentry.plugins import register
 from sentry.plugins.bases.notify import NotificationPlugin, NotificationConfigurationForm
 from sentry.utils.cache import cache
+from sentry.utils.http import absolute_uri
 
 import re
 
@@ -149,8 +150,7 @@ class MailProcessor(NotificationPlugin):
         subject = '[%s] %s: %s' % (project.name.encode('utf-8'), event.get_level_display().upper().encode('utf-8'),
             event.error().encode('utf-8').splitlines()[0])
 
-        link = '%s%s' % (settings.URL_PREFIX,
-            reverse('sentry-group', args=[group.team.slug, group.project.slug, group.id]))
+        link = absolute_uri(reverse('sentry-group', args=[group.team.slug, group.project.slug, group.id]))
 
         body = self.get_plaintext_body(group, event, link, interface_list)
 
