@@ -2,11 +2,14 @@
 sentry.tasks
 ~~~~~~~~~~~~
 
-:copyright: (c) 2010-2012 by the Sentry Team, see AUTHORS for more details.
+:copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
 
+import sentry.tasks.check_alerts  # NOQA
 import sentry.tasks.cleanup  # NOQA
 import sentry.tasks.fetch_source  # NOQA
 import sentry.tasks.index  # NOQA
 import sentry.tasks.store  # NOQA
+import sentry.tasks.post_process  # NOQA
+import sentry.tasks.process_buffer  # NOQA
