@@ -25,7 +25,8 @@ from sentry.conf import settings
 from sentry.constants import (SORT_OPTIONS, SEARCH_SORT_OPTIONS,
     SORT_CLAUSES, MYSQL_SORT_CLAUSES, SQLITE_SORT_CLAUSES, MEMBER_USER,
     SCORE_CLAUSES, MYSQL_SCORE_CLAUSES, SQLITE_SCORE_CLAUSES,
-    ORACLE_SORT_CLAUSES, ORACLE_SCORE_CLAUSES)
+    ORACLE_SORT_CLAUSES, ORACLE_SCORE_CLAUSES,
+    MSSQL_SORT_CLAUSES, MSSQL_SCORE_CLAUSES)
 from sentry.filters import get_filters
 from sentry.models import Project, Group, Event, SearchDocument, Activity
 from sentry.permissions import can_admin_group, can_create_projects
@@ -112,6 +113,9 @@ def _get_group_list(request, project):
     elif engine.startswith('oracle'):
         score_clause = ORACLE_SORT_CLAUSES.get(sort)
         filter_clause = ORACLE_SCORE_CLAUSES.get(sort)
+    elif engine in ('django_pytds', 'sqlserver_ado', 'sql_server.pyodbc'):
+        score_clause = MSSQL_SORT_CLAUSES.get(sort)
+        filter_clause = MSSQL_SCORE_CLAUSES.get(sort)
     else:
         score_clause = SORT_CLAUSES.get(sort)
         filter_clause = SCORE_CLAUSES.get(sort)
@@ -129,7 +133,7 @@ def _get_group_list(request, project):
         event_list = event_list.extra(
             select={'sort_value': score_clause},
         )
-        # HACK: dont sort by the same column twice
+        # HACK: don't sort by the same column twice
         if sort == 'date':
             event_list = event_list.order_by('-last_seen')
         else:
